@@ -1,4 +1,17 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import os
 import sys
@@ -17,10 +30,17 @@ except ImportError:
     openstackdocstheme = None
 
 # openstackdocstheme options
+
+# Deprecated options for docstheme < 2.2.0, can be removed once
+# pbr stops supporting py27.
 repository_name = 'openstack/pbr'
 bug_project = 'pbr'
 bug_tag = ''
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
+# New options with openstackdocstheme >=2.2.0
+openstackdocs_repo_name = 'openstack/pbr'
+openstackdocs_auto_name = False
+openstackdocs_bug_project = 'pbr'
+openstackdocs_bug_tag = ''
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
